#
# spec file for package lua-luasocket
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor lua51
%define mod_name luasocket
Version:        3.1.0
Release:        3.4
Summary:        Network support for the Lua language
License:        MIT
Group:          Development/Languages/Other
URL:            https://github.com/lunarmodules/luasocket
Source:         %{mod_name}-%{version}.tar.xz
Patch0:         luasocket-makefile.patch
BuildRequires:  %{flavor}-devel
BuildRequires:  lua-macros
Requires:       %{flavor}
%lua_provides
%lua_provides -e
%if "%{flavor}" == ""
Name:           lua-%{mod_name}
ExclusiveArch:  do_not_build
%else
Name:           %{flavor}-%{mod_name}
Recommends:     %{flavor}-%{mod_name}-doc
%endif

%description
LuaSocket is a Lua extension library that is composed by two parts: a C core
that provides support for the TCP and UDP transport layers, and a set of Lua
modules that add support for functionality commonly needed by applications
that deal with the Internet.

Among the support modules, the most commonly used implement the SMTP, HTTP
and FTP. In addition there are modules for MIME, URL handling and LTN12.

%package devel
Summary:        Header files for %{flavor}-%{mod_name}
Group:          Development/Languages/Other
Requires:       %{flavor}-%{mod_name} = %{version}

%description devel
This subpackage contains header files for developing applications that
want to make use of %{flavor}-%{mod_name}.

%package doc
Summary:        Documentation for %{flavor}-%{mod_name}
Group:          Development/Languages/Other
BuildArch:      noarch

%description doc
This subpackage contains documentation for %{flavor}-%{mod_name}.

%prep
%autosetup -p1 -n %{mod_name}-%{version}

%build
%{_bindir}/iconv -f ISO8859-1 -t UTF8 LICENSE >LICENSE.UTF8
mv -f LICENSE.UTF8 LICENSE
make %{?_smp_mflags} OPTFLAGS="%{optflags} -fPIC -I%{lua_incdir}" linux

%install
make install-unix OPTFLAGS="%{optflags}" INSTALL_TOP=%{buildroot} INSTALL_TOP_CDIR=%{buildroot}%{lua_archdir} INSTALL_TOP_LDIR=%{buildroot}%{lua_noarchdir}

# install development files
install -d %{buildroot}%{lua_incdir}
install -p -m 0644 src/*.h %{buildroot}%{lua_incdir}

%files
%license LICENSE
%{lua_archdir}/mime
%{lua_archdir}/socket
%{lua_noarchdir}/ltn12.lua
%{lua_noarchdir}/mime.lua
%{lua_noarchdir}/socket.lua
%{lua_noarchdir}/socket/

%files devel
%dir %{lua_incdir}
%{lua_incdir}/*.h

%files doc
%doc docs/*
%doc README.md

%changelog
* Thu Feb 22 2024 Michael Vetter <mvetter@suse.com>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Wed Jan 25 2023 Michal Suchanek <msuchanek@suse.de>
- Fix unowned %%{lua_incdir} directory.
* Wed Jan 25 2023 Michal Suchanek <msuchanek@suse.de>
- Fix missing dependency on lua-macros (boo#1205612)
* Sat Aug 20 2022 Gordon Leung <pirateclip@protonmail.com>
  rebase: luasocket-makefile.patch
  fix: W: package-with-huge-docs 69%%
- Create a speperate doc package, lua*-luasocket will recommend it
  fix: update URL
* Sat Aug 20 2022 pirateclip@protonmail.com
- Update to version 3.1.0:
  * chore: Release v3.1.0
  * ci: Echo correct platform in job title
  * fix(build): Use gai_strerrorA not gai_strerror on Windows
  * feat(tcp): Add support for TCP Defer Accept
  * feat(tcp): Add support for TCP Fast Open
  * chore(rockspec): Move recent PR change to proper rockspec (#384)
  * fix(rockspec): Fixup Windows (mingw32) builds (#383)
  * chore: Update internal version references to match release (#370)
  * chore: Release v3.0.0
  * chore: Copy-edit description in dev rockspec
* Sun Jul 11 2021 Callum Farmer <gmbr3@opensuse.org>
- Add a more useful dependency name
* Fri Feb 26 2021 Callum Farmer <gmbr3@opensuse.org>
- Fix provides naming
* Wed Jan 27 2021 Callum Farmer <gmbr3@opensuse.org>
- Use %%lua_provides macro
* Mon Jul  6 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Switch to multibuild and add lua54 build target.
* Tue Mar 12 2019 Martin Hauke <mardnh@gmx.de>
- Create subpackage -devel
  * Package header files
* Tue Oct 31 2017 tchvatal@suse.com
- Drop lua52-luasocket to obsolete lua52 from distribution
* Mon Oct 16 2017 tchvatal@suse.com
- Provide/Obsolete luasocket to avoid conflict wrt bsc#1063306
* Thu Jul 27 2017 tchvatal@suse.com
- Switch from multibuild for now as it can't be in rings and this
  is a ring package
* Fri Jul 14 2017 tchvatal@suse.com
- Update to version 3.0~rc1+git20170515.5a17f79:
  * make protect_segment in url.lua rfc compliant
  * fix for Lua 5.3 built without number / string conversion
  * correct typo
  * Fix issue #196
  * Preserve path when parsing urls.
  * Fix typo
- Switch to multibuild package
- luasocket-makefile.patch refresh to apply on new version
* Tue Jul 11 2017 tchvatal@suse.com
- Fix build with namespaced lua
* Thu Sep 15 2016 mvetter@suse.com
- Using Requires: Lua(API) = 5.1 instead of Requires: lua51 as
  suggested by DimStar in SR#423700
* Mon Oct 20 2014 i@marguerite.su
- update version 3.0~rc1+git20140716
* Sat Feb 22 2014 i@marguerite.su
- initial version 3.0~rc1
- copied from luasocket
